@@ -17,19 +17,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/bin/python",
 
         # Package versions
-        contourpy_version="1.1.0",
-        meson_version="1.1.1",
-        mesonpy_version="0.13.1",
-        pybind11_version="2.10.4",
+        contourpy_version="1.1.1",
+        meson_version="1.2.1",
+        mesonpy_version="0.14.0",
+        pybind11_version="2.11.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.1.0/.mesonpy-z574fkxc/build/lib/contourpy/util",
-        source_dir=r"/build/python-contourpy/src/contourpy-1.1.0/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy-1.1.1/.mesonpy-ef6ml4vw/lib/contourpy/util",
+        source_dir=r"/build/python-contourpy/src/contourpy-1.1.1/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.1.0/.mesonpy-z574fkxc/build/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.1.1/.mesonpy-ef6ml4vw/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
